==> jc-1.4.0.tar.gz: soot/options/LCMOptions.h <==
// public class soot.options.LCMOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class aa464a1009a5bd65 soot_options_LCMOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_LCMOptions_H_
#define _JC_soot_options_LCMOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_LCMOptions$sub_refs	_jc_soot_options_LCMOptions$sub_refs;
typedef struct _jc_soot_options_LCMOptions$sub_nonrefs	_jc_soot_options_LCMOptions$sub_nonrefs;
typedef struct _jc_soot_options_LCMOptions$refs	_jc_soot_options_LCMOptions$refs;
typedef struct _jc_soot_options_LCMOptions$nonrefs	_jc_soot_options_LCMOptions$nonrefs;
typedef struct _jc_soot_options_LCMOptions$object	_jc_soot_options_LCMOptions$object;

typedef struct _jc_soot_options_LCMOptions$fields_struct	_jc_soot_options_LCMOptions$fields_struct;
typedef const struct _jc_soot_options_LCMOptions$vmethods	_jc_soot_options_LCMOptions$vmethods;
typedef const struct _jc_soot_options_LCMOptions$vtable	_jc_soot_options_LCMOptions$vtable;
typedef const struct _jc_soot_options_LCMOptions$vtype	_jc_soot_options_LCMOptions$vtype;

// Class fields structure
struct _jc_soot_options_LCMOptions$fields_struct {
	jint	safety__5fmedium;
	jint	safety__5fsafe;
	jint	safety__5funsafe;
};
extern _jc_soot_options_LCMOptions$fields_struct _jc_soot_options_LCMOptions$class_fields;

// Constructors
extern void _jc_soot_options_LCMOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_LCMOptions$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_options_LCMOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_LCMOptions$object *);
extern jboolean _jc_soot_options_LCMOptions$method$naive__5fside__5feffect$5a8a3f3892ad8319(_jc_env *, struct _jc_soot_options_LCMOptions$object *);
extern jint _jc_soot_options_LCMOptions$method$safety$5c6635b685a7083e(_jc_env *, struct _jc_soot_options_LCMOptions$object *);
extern jboolean _jc_soot_options_LCMOptions$method$unroll$518d67e8821f27c5(_jc_env *, struct _jc_soot_options_LCMOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_LCMOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_LCMOptions$method_info$naive__5fside__5feffect$5a8a3f3892ad8319;
extern _jc_method _jc_soot_options_LCMOptions$method_info$safety$5c6635b685a7083e;
extern _jc_method _jc_soot_options_LCMOptions$method_info$unroll$518d67e8821f27c5;

// Virtual methods structure
struct _jc_soot_options_LCMOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_LCMOptions$object *);
	jboolean	(*naive__5fside__5feffect$5a8a3f3892ad8319)(_jc_env *, struct _jc_soot_options_LCMOptions$object *);
	jint	(*safety$5c6635b685a7083e)(_jc_env *, struct _jc_soot_options_LCMOptions$object *);
	jboolean	(*unroll$518d67e8821f27c5)(_jc_env *, struct _jc_soot_options_LCMOptions$object *);
};

// Vtable
struct _jc_soot_options_LCMOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_LCMOptions$vmethods	soot_options_LCMOptions;
};

// Vtype
struct _jc_soot_options_LCMOptions$vtype {
	_jc_type			type;
	_jc_soot_options_LCMOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_LCMOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_LCMOptions$refs {
    _jc_soot_options_LCMOptions$sub_refs	soot_options_LCMOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_LCMOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_LCMOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_LCMOptions$sub_nonrefs	soot_options_LCMOptions;
};

// Object instance structure
struct _jc_soot_options_LCMOptions$object {
	_jc_soot_options_LCMOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_LCMOptions$vtype	*vtype;
	_jc_soot_options_LCMOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_LCMOptions$vtype _jc_soot_options_LCMOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_LCMOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_LCMOptions$class_object;

#endif	/* _JC_soot_options_LCMOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/LCMOptions.h <==
// public class soot.options.LCMOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class aa464a1009a5bd65 soot_options_LCMOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_LCMOptions_H_
#define _JC_soot_options_LCMOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_LCMOptions$sub_refs	_jc_soot_options_LCMOptions$sub_refs;
typedef struct _jc_soot_options_LCMOptions$sub_nonrefs	_jc_soot_options_LCMOptions$sub_nonrefs;
typedef struct _jc_soot_options_LCMOptions$refs	_jc_soot_options_LCMOptions$refs;
typedef struct _jc_soot_options_LCMOptions$nonrefs	_jc_soot_options_LCMOptions$nonrefs;
typedef struct _jc_soot_options_LCMOptions$object	_jc_soot_options_LCMOptions$object;

typedef struct _jc_soot_options_LCMOptions$fields_struct	_jc_soot_options_LCMOptions$fields_struct;
typedef const struct _jc_soot_options_LCMOptions$vmethods	_jc_soot_options_LCMOptions$vmethods;
typedef const struct _jc_soot_options_LCMOptions$vtable	_jc_soot_options_LCMOptions$vtable;
typedef const struct _jc_soot_options_LCMOptions$vtype	_jc_soot_options_LCMOptions$vtype;

// Class fields structure
struct _jc_soot_options_LCMOptions$fields_struct {
	jint	safety__5fmedium;
	jint	safety__5fsafe;
	jint	safety__5funsafe;
};
extern _jc_soot_options_LCMOptions$fields_struct _jc_soot_options_LCMOptions$class_fields;

// Constructors
extern void _jc_soot_options_LCMOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_LCMOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_options_LCMOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_LCMOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_LCMOptions$method$naive__5fside__5feffect$5a8a3f3892ad8319(_jc_env *, struct _jc_soot_options_LCMOptions$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_options_LCMOptions$method$safety$5c6635b685a7083e(_jc_env *, struct _jc_soot_options_LCMOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_LCMOptions$method$unroll$518d67e8821f27c5(_jc_env *, struct _jc_soot_options_LCMOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_LCMOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_LCMOptions$method_info$naive__5fside__5feffect$5a8a3f3892ad8319;
extern _jc_method _jc_soot_options_LCMOptions$method_info$safety$5c6635b685a7083e;
extern _jc_method _jc_soot_options_LCMOptions$method_info$unroll$518d67e8821f27c5;

// Virtual methods structure
struct _jc_soot_options_LCMOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_LCMOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*naive__5fside__5feffect$5a8a3f3892ad8319)(_jc_env *, struct _jc_soot_options_LCMOptions$object *) _JC_JCNI_ATTR;
	jint	(*safety$5c6635b685a7083e)(_jc_env *, struct _jc_soot_options_LCMOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*unroll$518d67e8821f27c5)(_jc_env *, struct _jc_soot_options_LCMOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_LCMOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_LCMOptions$vmethods	soot_options_LCMOptions;
};

// Vtype
struct _jc_soot_options_LCMOptions$vtype {
	_jc_type			type;
	_jc_soot_options_LCMOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_LCMOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_LCMOptions$refs {
    _jc_soot_options_LCMOptions$sub_refs	soot_options_LCMOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_LCMOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_LCMOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_LCMOptions$sub_nonrefs	soot_options_LCMOptions;
};

// Object instance structure
struct _jc_soot_options_LCMOptions$object {
	_jc_soot_options_LCMOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_LCMOptions$vtype	*vtype;
	_jc_soot_options_LCMOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_LCMOptions$vtype _jc_soot_options_LCMOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_LCMOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_LCMOptions$class_object;

#endif	/* _JC_soot_options_LCMOptions_H_ */
